Class: RbFind::Entry
- Inherits:
-
Object
show all
- Includes:
- Csv
- Defined in:
- lib/rbfind.rb
Constant Summary
collapse
- ARROW =
" -> "
Constants included
from Csv
Csv::COLON
Instance Attribute Summary collapse
Class Method Summary
collapse
Instance Method Summary
collapse
Methods included from Csv
#colsep, #csv, outfile, putl, #spcsep, #tabsep
Constructor Details
#initialize(filename, walk) ⇒ Entry
Returns a new instance of Entry.
413
414
415
416
417
|
# File 'lib/rbfind.rb', line 413
def initialize filename, walk
@walk = walk
@prev, @name = walk.current, filename.dup.freeze
@path = join_path @name
end
|
Dynamic Method Handling
This class handles dynamic methods through the method_missing method
#method_missing(sym, *args, &block) ⇒ Object
464
465
466
467
468
469
470
|
# File 'lib/rbfind.rb', line 464
def method_missing sym, *args, &block
if stat.respond_to? sym then
stat.send sym, *args, &block
else
super
end
end
|
Instance Attribute Details
#name ⇒ Object
Returns the value of attribute name.
411
412
413
|
# File 'lib/rbfind.rb', line 411
def name
@name
end
|
#path ⇒ Object
Returns the value of attribute path.
411
412
413
|
# File 'lib/rbfind.rb', line 411
def path
@path
end
|
Class Method Details
.colored(arg, num) ⇒ Object
Also known as:
coloured
825
826
827
828
|
# File 'lib/rbfind.rb', line 825
def colored arg, num
colors col_str
"\e[#{@colors[num]}m#{arg}\e[m"
end
|
.colors(str) ⇒ Object
Also known as:
colours
831
832
833
834
835
836
837
838
839
840
841
842
843
844
845
846
847
848
849
850
851
852
853
854
855
856
|
# File 'lib/rbfind.rb', line 831
def colors str
@colors ||= if str =~ /:/ then
h = {}
(str.split ":").each { |a|
t, c = a.split "="
h[ t] = c
}
%w(rs or di ln so pi ex bd cd su sg tw ow - -).map { |t| h[ t] }
else
cols = []
str.scan /(.)(.)/i do
fg, bg = $~.captures.map { |x| x.downcase.ord - ?a.ord }
a = []
case fg
when 0..7 then a.push 30 + fg
end
a.push 1 if $1 == $1.upcase
case bg
when 0..7 then a.push 40 + bg
end
e = a.join ";"
cols.push e
end
cols
end
end
|
Instance Method Details
#aage ⇒ Object
491
|
# File 'lib/rbfind.rb', line 491
def aage ; @walk.start - stat.atime ; end
|
#arrow ⇒ Object
566
567
568
|
# File 'lib/rbfind.rb', line 566
def arrow
ARROW + (File.readlink @path) if symlink?
end
|
#binary?(n = 1) ⇒ Boolean
Also known as:
bin?
:call-seq:
binary?( n = 1) -> true or false
Test whether the first n blocks contain null characters.
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
|
# File 'lib/rbfind.rb', line 691
def binary? n = 1
bs = stat.blksize
open { |file|
loop do
if n then
break if n <= 0
n -= 1
end
b = file.read bs
b or break
return true if b[ "\0"]
end
}
false
end
|
#birthage ⇒ Object
Also known as:
bage
503
|
# File 'lib/rbfind.rb', line 503
def birthage ; @walk.start - birthtime ; end
|
#birthtime ⇒ Object
498
499
500
501
502
|
# File 'lib/rbfind.rb', line 498
def birthtime
stat.birthtime
rescue NotImplementedError
File.birthtime @path
end
|
#broken_link? ⇒ Boolean
Also known as:
broken?
556
557
558
559
560
561
562
|
# File 'lib/rbfind.rb', line 556
def broken_link?
return unless symlink?
rstat
false
rescue
true
end
|
#cage ⇒ Object
494
|
# File 'lib/rbfind.rb', line 494
def cage ; @walk.start - stat.ctime ; end
|
#carrow ⇒ Object
769
770
771
772
|
# File 'lib/rbfind.rb', line 769
def carrow
r = creadlink
ARROW + r if r
end
|
#cfullpath ⇒ Object
757
|
# File 'lib/rbfind.rb', line 757
def cfullpath ; color fullpath ; end
|
#cfullpath! ⇒ Object
759
|
# File 'lib/rbfind.rb', line 759
def cfullpath! ; color fullpath! ; end
|
#cname ⇒ Object
755
|
# File 'lib/rbfind.rb', line 755
def cname ; color name ; end
|
#color(arg) ⇒ Object
Also known as:
colour
775
776
777
|
# File 'lib/rbfind.rb', line 775
def color arg
color_stat arg, stat
end
|
#contains?(name) ⇒ Boolean
:call-seq:
contains?( name) -> true or false
Check whether a directory contains an entry.
589
590
591
592
593
594
595
|
# File 'lib/rbfind.rb', line 589
def contains? name
p = File.join @path, name
File.lstat p
true
rescue
false
end
|
#count ⇒ Object
432
|
# File 'lib/rbfind.rb', line 432
def count ; @walk.count ; end
|
#cpath ⇒ Object
756
|
# File 'lib/rbfind.rb', line 756
def cpath ; color path ; end
|
#cpath! ⇒ Object
758
|
# File 'lib/rbfind.rb', line 758
def cpath! ; color path! ; end
|
#creadlink ⇒ Object
761
762
763
764
765
766
767
|
# File 'lib/rbfind.rb', line 761
def creadlink
l = readlink
if l then
s = rstat rescue nil
color_stat l, s
end
end
|
#cyclic? ⇒ Boolean
478
479
480
481
482
483
484
485
486
487
488
|
# File 'lib/rbfind.rb', line 478
def cyclic?
e = self
loop do
e = e.prev
e or break
if File.identical? e.path, @path then
return true
end
end
false
end
|
#depth ⇒ Object
433
|
# File 'lib/rbfind.rb', line 433
def depth ; @walk.depth ; end
|
#directory? ⇒ Boolean
Also known as:
dir?
473
|
# File 'lib/rbfind.rb', line 473
def directory? ; stat.directory? ; end
|
#dirname ⇒ Object
449
450
451
|
# File 'lib/rbfind.rb', line 449
def dirname
File.basename File.dirname fullpath
end
|
#done ⇒ Object
Also known as:
done!
717
|
# File 'lib/rbfind.rb', line 717
def done ; raise Done ; end
|
#empty? ⇒ Boolean
:call-seq:
empty?() -> true or false
Look up if the directory is empty. If the object is not a directory or not accessible, nil is returned.
578
579
580
581
582
|
# File 'lib/rbfind.rb', line 578
def empty?
Dir.open @path do |d| d.each_child { |f| return false } end
true
rescue Errno::ENOTDIR
end
|
#entries ⇒ Object
Also known as:
children
:call-seq:
entries() -> ary
Return all entries in an array. If the object is not a directory, nil is returned.
603
604
605
606
|
# File 'lib/rbfind.rb', line 603
def entries
Dir.open @path do |d| d.children end
rescue Errno::ENOTDIR
end
|
#ext ⇒ Object
454
|
# File 'lib/rbfind.rb', line 454
def ext ; File.extname name ; end
|
#filesize ⇒ Object
:call-seq:
filesize => nil or int
filesize { |size| ... } => obj
Returns the files size. When the object is not a regular file, nil will be returned or the block will not be called.
513
514
515
516
517
518
519
520
|
# File 'lib/rbfind.rb', line 513
def filesize
stat.file? or return
if block_given? then
yield stat.size
else
stat.size
end
end
|
#fullpath ⇒ Object
436
|
# File 'lib/rbfind.rb', line 436
def fullpath ; @fullpath ||= File.absolute_path @path ; end
|
#fullpath! ⇒ Object
447
|
# File 'lib/rbfind.rb', line 447
def fullpath! ; append_slash fullpath ; end
|
#grep(re, color = nil) ⇒ Object
671
672
673
674
675
676
677
678
679
680
681
682
683
684
|
# File 'lib/rbfind.rb', line 671
def grep re, color = nil
case color
when /\A\d+(?:;\d+)*\z/, nil, false then
when true then color = "31;1" else raise "Illegal color spec: #{color}"
end
lines { |l,i|
l.scrub!
l =~ re or next
color and l = "#$`\e[#{color}m#$&\e[m#$'"
colsep @path, i, l
true
}
end
|
#group ⇒ Object
544
545
546
|
# File 'lib/rbfind.rb', line 544
def group
get_group stat.gid
end
|
#group! ⇒ Object
548
549
550
551
|
# File 'lib/rbfind.rb', line 548
def group!
g = stat.gid
g == Process.gid ? "." : (get_group g)
end
|
#hidden? ⇒ Boolean
457
|
# File 'lib/rbfind.rb', line 457
def hidden? ; name =~ /^\./ ; end
|
#inspect ⇒ Object
419
|
# File 'lib/rbfind.rb', line 419
def inspect ; "<##{self.class} #@path>" ; end
|
#lines ⇒ Object
:call-seq:
lines { |l,i| ... } -> nil
Yield line by line together with the line number i.
657
658
659
660
661
662
663
664
665
666
667
668
669
|
# File 'lib/rbfind.rb', line 657
def lines
block_given? or return lines do end
r = false
open { |file|
n = 0
file.each_line { |l|
l.chomp!
n += 1
r ||= true if yield l, n
}
r
}
end
|
#mage ⇒ Object
Also known as:
age
492
|
# File 'lib/rbfind.rb', line 492
def mage ; @walk.start - stat.mtime ; end
|
#mode ⇒ Object
461
|
# File 'lib/rbfind.rb', line 461
def mode ; stat.mode ; end
|
#novcs ⇒ Object
Also known as:
no_vcs
723
724
725
|
# File 'lib/rbfind.rb', line 723
def novcs
prune if vcs?
end
|
#now ⇒ Object
434
|
# File 'lib/rbfind.rb', line 434
def now ; @walk.start ; end
|
#open(&block) ⇒ Object
:call-seq:
open() { |h| ... } -> obj
Open the file for reading. If the object is not a regular file, nothing will be done.
621
622
623
624
625
626
|
# File 'lib/rbfind.rb', line 621
def open &block
@ostat ||= $stdout.stat
@ostat.identical? @path and
raise "Refusing to open output file."
File.open @path, &block if file?
end
|
#path! ⇒ Object
446
|
# File 'lib/rbfind.rb', line 446
def path! ; append_slash path ; end
|
#prune ⇒ Object
Also known as:
prune!
720
|
# File 'lib/rbfind.rb', line 720
def prune ; raise Prune ; end
|
#read(n = nil) ⇒ Object
:call-seq:
read( n = nil) -> str or nil
read( n = nil) { |b| ... } -> nil
Read the first n bytes or return nil for others than regular files. nil reads to end of file. If a block is given, chonks of n bytes (or all) will be yielded.
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
|
# File 'lib/rbfind.rb', line 636
def read n = nil
open { |o|
if block_given? then
if n then
while (r = o.read n) do
yield r
end
else
yield o.read
end
else
o.read n
end
}
end
|
#readlink ⇒ Object
554
|
# File 'lib/rbfind.rb', line 554
def readlink ; File.readlink @path if symlink? ; end
|
#rename(newname) ⇒ Object
Also known as:
mv
732
733
734
735
736
737
738
739
740
741
|
# File 'lib/rbfind.rb', line 732
def rename newname
@name = newname
newname == (File.basename newname) or
raise "Rename to `#{newname}' may not be a path."
p = join_path newname
(File.exist? p) and raise "Rename to `#{p}` would overwrite."
File.rename @path, p
@name, @path = newname.dup.freeze, p
reset
end
|
#rm ⇒ Object
744
745
746
747
748
749
750
751
752
|
# File 'lib/rbfind.rb', line 744
def rm
if directory? then
Dir.rmdir @path
else
File.unlink @path
end
@name = @path = nil
reset
end
|
#rstat ⇒ Object
439
|
# File 'lib/rbfind.rb', line 439
def rstat ; @rstat ||= File.stat @path ; end
|
#stat ⇒ Object
438
|
# File 'lib/rbfind.rb', line 438
def stat ; @stat ||= File.lstat @path ; end
|
#symlink? ⇒ Boolean
476
|
# File 'lib/rbfind.rb', line 476
def symlink? ; stat.symlink? ; end
|
#user ⇒ Object
Also known as:
owner
533
534
535
|
# File 'lib/rbfind.rb', line 533
def user
get_user stat.uid
end
|
#user! ⇒ Object
Also known as:
owner!
538
539
540
541
|
# File 'lib/rbfind.rb', line 538
def user!
u = stat.uid
u == Process.uid ? "." : (get_user u)
end
|
#vcs? ⇒ Boolean
610
611
612
|
# File 'lib/rbfind.rb', line 610
def vcs?
%w(CVS .svn .git .hg .fslckout).include? name
end
|
#vimswap? ⇒ Boolean
708
709
710
711
712
713
|
# File 'lib/rbfind.rb', line 708
def vimswap?
if name =~ /\A(\..+)?\.sw[a-z]\z/i then
mark = read 5
mark == "b0VIM"
end
end
|
#visible? ⇒ Boolean
458
|
# File 'lib/rbfind.rb', line 458
def visible? ; not hidden? ; end
|
#without_ext ⇒ Object
455
|
# File 'lib/rbfind.rb', line 455
def without_ext ; name[ /^(.+?)(?:\.[^.]+)?$/, 1 ].to_s ; end
|